@@ -31,12 +31,17 @@ class Rethink_DBS(GeneralData):
         r.set_loop_type('asyncio')
         self.r = r
 
+    def __repr__(self):
+        return f"Rethink_DBS({self.default_db}, {self.address})"
+
+    def __str__(self):
+        return f"Rethink_DBS({self.default_db}, {self.address})"
+
     async def msg_log(self, msg, level):
         if self:
             self.save_log(msg, level)
 
     async def async_connect(self, loop=None, *args, **kwargs):
-        self.active_conn = True
         self.session = None
         try:
             if self.default_db:
@@ -53,13 +58,18 @@ class Rethink_DBS(GeneralData):
                                                     port=dbport,
                                                     **kwargs)
                 self.done_conn = True
+                self.active_conn = True
                 self.logger.info(
                     f"Connected to RethinkDB with database {self.default_db}")
             else:
-                self.session = await self.r.connect(host=self.host,
-                                                    port=self.port)
+                self.session = await self.r.connect(
+                    host=self.host,
+                    port=self.port)
                 self.logger.info(
-                    "Connected to RethinkDB without database selected")
+                    """Connected to RethinkDB without database
+                    selected""")
+                self.done_conn = True
+                self.active_conn = True
         except (RqlDriverError, RqlError) as r_error:
             kwargs["origin_exception"] = RqlError
             msg = f'''PD_CONN, ConnectionClosed {r_error} connection....'''
@@ -352,7 +362,6 @@ class Rethink_DBS(GeneralData):
         if task:
             task.set_name(f"get_data_filter_{table_name}")
         dbname = self.dbname
-        print("Reading from", dbname, table_name)
         index = filter_opt.get('index')
         if table_name in self.tables.get(self.default_db, {}):
             options = {'read_mode': 'single'}
